@@ -100,6 +100,15 @@ public class KameletsCatalogTest {
         assertTrue(c.isEmpty());
     }
 
+    @Test
+    void testGetKameletsByNamespace() throws Exception {
+        List<Kamelet> c = catalog.getKameletsByNamespace("AWS");
+        assertTrue(!c.isEmpty());
+        assertTrue(c.size() == 27);
+        c = catalog.getKameletsByGroups("Not-existing-group");
+        assertTrue(c.isEmpty());
+    }
+
     @Test
     void testGetKameletsDependencies() throws Exception {
         List<String> deps = catalog.getKameletDependencies("aws-sqs-source");
